@@ -736,7 +736,7 @@ class ImgCompounder:
                             top = 0 + self.camera_border_top
                             if camera_border_text['flip'] == 1:
                                 text_image = text_image.rotate(180)
-                                top = self.camera_border_top + (self.camera_border_stroke_width - text_height) / 2
+                                top = self.camera_border_top + (self.camera_border_stroke_width - text_height) / 2 + 3
                             compound_img.paste(text_image, (int(left), int(top)), text_image)
                         if camera_border_text['angle'] == 45:
                             arcs_text_img = self.__draw_arcs_text_img(text=text,
@@ -757,7 +757,7 @@ class ImgCompounder:
                                                      border_stroke_width=self.camera_border_stroke_width)
                             left = self.camera_border_width - self.camera_border_stroke_width + \
                                    (self.camera_border_stroke_width - text_height) / 2 + \
-                                   self.camera_border_left
+                                   self.camera_border_left  + 3
                             top = camera_border_text['top'] + self.camera_border_top
                             text_image = text_image.transpose(Image.ROTATE_270)
                             if camera_border_text['flip'] == 1:
@@ -782,7 +782,7 @@ class ImgCompounder:
                                                      border_stroke_width=self.camera_border_stroke_width)
                             left = self.camera_border_left + camera_border_text['left']
                             top = self.camera_border_top + self.camera_border_height - self.camera_border_stroke_width + \
-                                  (self.camera_border_stroke_width - text_height) / 2
+                                  (self.camera_border_stroke_width - text_height) / 2 + 3
                             text_image = text_image.transpose(Image.ROTATE_180)
                             if camera_border_text['flip'] == 1:
                                 text_image = text_image.rotate(180)
@@ -810,7 +810,7 @@ class ImgCompounder:
                             text_image = text_image.transpose(Image.ROTATE_90)
                             if camera_border_text['flip'] == 1:
                                 text_image = text_image.rotate(180)
-                                left = self.camera_border_left + (self.camera_border_stroke_width - text_height) / 2
+                                left = self.camera_border_left + (self.camera_border_stroke_width - text_height) / 2 + 3
                             compound_img.paste(text_image, (int(left), int(top)), text_image)
                         if camera_border_text['angle'] == 315:
                             arcs_text_img = self.__draw_arcs_text_img(text=text,
